pub enum Command {
Start,
Stop,
Pause,
Resume,
}Expand description
The commands are sent by the service control manager to the service through the closure or callback
passed to the service run method.
Variants
Start
The start command is sent when the service first starts.
Stop
The stop command is sent when the service is stopping just prior to process termination.
This command will only be sent if the can_stop method is called as part of construction.
Pause
The pause command is sent when the service is being paused but not stopping.
This command will only be sent if the can_pause method is called as part of construction.
Resume
The resume command is sent when the service is being resumed following a pause.
This command will only be sent if the can_pause method is called as part of construction.