Struct Service

pub struct Service(/* private fields */);
A service builder, providing control over what commands the service supports before the service begins to run.

Implementations

Source

impl Service

pub fn new() -> Self

Creates a new Service object.

By default, the service does not accept any service commands other than start.

pub fn can_stop(&mut self) -> &mut Self

The service accepts stop and shutdown commands.

pub fn can_pause(&mut self) -> &mut Self

The service accepts pause and resume commands.

pub fn run<F: FnMut(Command) + Send + Sync>(&self, callback: F) -> !

Runs the service with the given callback closure to receive commands sent by the service control manager.

This method will block for the life of the service. It will never return and immediately terminate the current process after indicating to the service control manager that the service has stopped.